==> members-facade-1.0.1-mjh-20220507.101115-1-sources.jar: com/bizvane/members/facade/es/vo/WxQyFriendsSearchVo.java <==
package com.bizvane.members.facade.es.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import com.bizvane.members.facade.vo.qywx.MemberProperty;

import lombok.Data;

@Data
public class WxQyFriendsSearchVo implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = 1L;
    // 公司
    private Long sysCompanyId;
    // 品牌
    private Long brandId;
    // 好友userid
    private String externalUserId;
    // 导购
    private String guideId;
    // 联系人备注
    private String friendsComment;

    // 外联类型
    private String externalType;
    // unionId
    private String unionId;
    // 外部联系人姓名
    private String externalName;
    // 性别
    private Integer gender;
    // 会员code
    private String memberCode;
    // 等级id
    private Long levelId;
    // 服务店铺id
    private Long serviceStoreId;
    // 服务导购id
    private Long serviceGuideId;
    // 是否关注
    private Integer focus;
    // 会员手机
    private String phone;
    // 会员姓名
    private String memberName;

    // 是否会员
    private Boolean isMember;

    //昵称、备注、姓名、手机号
    private String condition;

    //性别集合
    private List<Integer> genderList;
    //粉丝属性集合
    private List<Integer> focusList;

    //备注/姓名
    private String nameCondition;


    // 会员属性
    private MemberProperty memberProperty;

    private Integer pageNumber;

    private Integer pageSize;

    // 服务导购id
    private List<Long> serviceGuideIds;
    
    private String serviceGuideKey;

    private List<Long> guideIds;
    
    private String guideKey;

    private List<String> unionIdList;

    //是否可以查被删除的好友
    private Boolean deleteEnable;

    private Integer friendStatus;


    private List<String> esMbrFriendsIdList;

    private Date beginCreateTime;
    private Date endCreateTime;

    private String onlineOrgCode;

    /**
     * 专属好友关系
     */
    private Boolean exclusiveFriend;

    /**
     * 当前操作人
     */
    private Long sysAccountId;

    private List<String> memberCodeList;

}

==> members-facade-1.0.7-mjh-20250901.101918-1-sources.jar: com/bizvane/members/facade/es/vo/WxQyFriendsSearchVo.java <==
package com.bizvane.members.facade.es.vo;

import com.bizvane.members.facade.vo.qywx.MemberProperty;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

@Data
public class WxQyFriendsSearchVo implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = 1L;
    // 公司
    private Long sysCompanyId;
    // 品牌
    private Long brandId;
    // 好友userid
    private String externalUserId;
    // 导购
    private String guideId;
    // 联系人备注
    private String friendsComment;

    // 外联类型
    private String externalType;
    // unionId
    private String unionId;
    // 外部联系人姓名
    private String externalName;
    // 性别
    private Integer gender;
    // 会员code
    private String memberCode;
    // 等级id
    private Long levelId;
    // 服务店铺id
    private Long serviceStoreId;
    // 服务导购id
    private Long serviceGuideId;
    // 是否关注
    private Integer focus;
    // 会员手机
    private String phone;
    // 会员姓名
    private String memberName;

    // 是否会员
    private Boolean isMember;

    //昵称、备注、姓名、手机号
    private String condition;

    //性别集合
    private List<Integer> genderList;
    //粉丝属性集合
    private List<Integer> focusList;

    //备注/姓名
    private String nameCondition;


    // 会员属性
    private MemberProperty memberProperty;

    private Integer pageNumber = 1;

    private Integer pageSize = 10;

    // 服务导购id
    private List<Long> serviceGuideIds;
    
    private String serviceGuideKey;

    private List<Long> guideIds;
    
    private String guideKey;

    private List<String> unionIdList;

    //是否可以查被删除的好友
    private Boolean deleteEnable;

    private Integer friendStatus;


    private List<String> esMbrFriendsIdList;

    private Date beginCreateTime;
    private Date endCreateTime;

    private String onlineOrgCode;

    /**
     * 专属好友关系
     */
    private Boolean exclusiveFriend;

    /**
     * 当前操作人
     */
    private Long sysAccountId;

    private List<String> memberCodeList;

}
